All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 0/3] staging:iio:adc:lpc32xx cleanup and staging graduation
@ 2017-02-05 13:06 Jonathan Cameron
  2017-02-05 13:06 ` [PATCH 1/3] staging:iio:adc:lpc32xx Apply consistent prefix to local defines Jonathan Cameron
                   ` (2 more replies)
  0 siblings, 3 replies; 7+ messages in thread
From: Jonathan Cameron @ 2017-02-05 13:06 UTC (permalink / raw)
  To: linux-iio; +Cc: Roland Stigge, Jonathan Cameron

There wasn't a whole lot wrong with this driver.  I suspect we simply
forgot about it.

Anyhow, simple boring cleanups and a move out of staging.

I've dissabled rename detection for the last patch to give an easy way
for people to directly review the code.

Jonathan Cameron (3):
  staging:iio:adc:lpc32xx Apply consistent prefix to local defines
  staging:iio:adc:lpc32xx rename local state structure to _state
  staging:iio:adc:lpc32xx Move out of staging.

 drivers/iio/adc/Kconfig               |  12 ++
 drivers/iio/adc/Makefile              |   1 +
 drivers/iio/adc/lpc32xx_adc.c         | 219 ++++++++++++++++++++++++++++++++++
 drivers/staging/iio/adc/Kconfig       |  12 --
 drivers/staging/iio/adc/Makefile      |   1 -
 drivers/staging/iio/adc/lpc32xx_adc.c | 215 ---------------------------------
 6 files changed, 232 insertions(+), 228 deletions(-)
 create mode 100644 drivers/iio/adc/lpc32xx_adc.c
 delete mode 100644 drivers/staging/iio/adc/lpc32xx_adc.c

-- 
2.11.1

^ permalink raw reply	[flat|nested] 7+ messages in thread

* [PATCH 1/3] staging:iio:adc:lpc32xx Apply consistent prefix to local defines
  2017-02-05 13:06 [PATCH 0/3] staging:iio:adc:lpc32xx cleanup and staging graduation Jonathan Cameron
@ 2017-02-05 13:06 ` Jonathan Cameron
  2017-02-11 11:20   ` Jonathan Cameron
  2017-02-05 13:06 ` [PATCH 2/3] staging:iio:adc:lpc32xx rename local state structure to _state Jonathan Cameron
  2017-02-05 13:07 ` [PATCH 3/3] staging:iio:adc:lpc32xx Move out of staging Jonathan Cameron
  2 siblings, 1 reply; 7+ messages in thread
From: Jonathan Cameron @ 2017-02-05 13:06 UTC (permalink / raw)
  To: linux-iio; +Cc: Roland Stigge, Jonathan Cameron

There was a bit of a random mixture going on here so change all prefixes
to LPC32XXAD_

Signed-off-by: Jonathan Cameron <jic23@kernel.org>
---
 drivers/staging/iio/adc/lpc32xx_adc.c | 54 +++++++++++++++++++----------------
 1 file changed, 29 insertions(+), 25 deletions(-)

-- 
2.11.1


^ permalink raw reply related	[flat|nested] 7+ messages in thread

* [PATCH 2/3] staging:iio:adc:lpc32xx rename local state structure to _state
  2017-02-05 13:06 [PATCH 0/3] staging:iio:adc:lpc32xx cleanup and staging graduation Jonathan Cameron
  2017-02-05 13:06 ` [PATCH 1/3] staging:iio:adc:lpc32xx Apply consistent prefix to local defines Jonathan Cameron
@ 2017-02-05 13:06 ` Jonathan Cameron
  2017-02-11 11:21   ` Jonathan Cameron
  2017-02-05 13:07 ` [PATCH 3/3] staging:iio:adc:lpc32xx Move out of staging Jonathan Cameron
  2 siblings, 1 reply; 7+ messages in thread
From: Jonathan Cameron @ 2017-02-05 13:06 UTC (permalink / raw)
  To: linux-iio; +Cc: Roland Stigge, Jonathan Cameron

Previously it was called _info with instances as info.  This caused some
confusion against the info structure that are used in the core of IIO.

Since this driver was written it's become a fairly strong convention to
use _state and st for instances so change to that.

Signed-off-by: Jonathan Cameron <jic23@kernel.org>
---
 drivers/staging/iio/adc/lpc32xx_adc.c | 46 +++++++++++++++++------------------
 1 file changed, 23 insertions(+), 23 deletions(-)

diff --git a/drivers/staging/iio/adc/lpc32xx_adc.c b/drivers/staging/iio/adc/lpc32xx_adc.c
index 5d13ff008a39..0de709b4288b 100644
--- a/drivers/staging/iio/adc/lpc32xx_adc.c
+++ b/drivers/staging/iio/adc/lpc32xx_adc.c
@@ -61,7 +61,7 @@
 
 #define LPC32XXAD_NAME "lpc32xx-adc"
 
-struct lpc32xx_adc_info {
+struct lpc32xx_adc_state {
 	void __iomem *adc_base;
 	struct clk *clk;
 	struct completion completion;
@@ -75,21 +75,21 @@ static int lpc32xx_read_raw(struct iio_dev *indio_dev,
 			    int *val2,
 			    long mask)
 {
-	struct lpc32xx_adc_info *info = iio_priv(indio_dev);
+	struct lpc32xx_adc_state *st = iio_priv(indio_dev);
 
 	if (mask == IIO_CHAN_INFO_RAW) {
 		mutex_lock(&indio_dev->mlock);
-		clk_prepare_enable(info->clk);
+		clk_prepare_enable(st->clk);
 		/* Measurement setup */
 		__raw_writel(LPC32XXAD_INTERNAL | (chan->address) |
 			     LPC32XXAD_REFp | LPC32XXAD_REFm,
-			     LPC32XXAD_SELECT(info->adc_base));
+			     LPC32XXAD_SELECT(st->adc_base));
 		/* Trigger conversion */
 		__raw_writel(LPC32XXAD_PDN_CTRL | LPC32XXAD_STROBE,
-			     LPC32XXAD_CTRL(info->adc_base));
-		wait_for_completion(&info->completion); /* set by ISR */
-		clk_disable_unprepare(info->clk);
-		*val = info->value;
+			     LPC32XXAD_CTRL(st->adc_base));
+		wait_for_completion(&st->completion); /* set by ISR */
+		clk_disable_unprepare(st->clk);
+		*val = st->value;
 		mutex_unlock(&indio_dev->mlock);
 
 		return IIO_VAL_INT;
@@ -120,19 +120,19 @@ static const struct iio_chan_spec lpc32xx_adc_iio_channels[] = {
 
 static irqreturn_t lpc32xx_adc_isr(int irq, void *dev_id)
 {
-	struct lpc32xx_adc_info *info = dev_id;
+	struct lpc32xx_adc_state *st = dev_id;
 
 	/* Read value and clear irq */
-	info->value = __raw_readl(LPC32XXAD_VALUE(info->adc_base)) &
-				LPC32XXAD_VALUE_MASK;
-	complete(&info->completion);
+	st->value = __raw_readl(LPC32XXAD_VALUE(st->adc_base)) &
+		LPC32XXAD_VALUE_MASK;
+	complete(&st->completion);
 
 	return IRQ_HANDLED;
 }
 
 static int lpc32xx_adc_probe(struct platform_device *pdev)
 {
-	struct lpc32xx_adc_info *info = NULL;
+	struct lpc32xx_adc_state *st = NULL;
 	struct resource *res;
 	int retval = -ENODEV;
 	struct iio_dev *iodev = NULL;
@@ -144,23 +144,23 @@ static int lpc32xx_adc_probe(struct platform_device *pdev)
 		return -ENXIO;
 	}
 
-	iodev = devm_iio_device_alloc(&pdev->dev, sizeof(*info));
+	iodev = devm_iio_device_alloc(&pdev->dev, sizeof(*st));
 	if (!iodev)
 		return -ENOMEM;
 
-	info = iio_priv(iodev);
+	st = iio_priv(iodev);
 
-	info->adc_base = devm_ioremap(&pdev->dev, res->start,
-						resource_size(res));
-	if (!info->adc_base) {
+	st->adc_base = devm_ioremap(&pdev->dev, res->start,
+				    resource_size(res));
+	if (!st->adc_base) {
 		dev_err(&pdev->dev, "failed mapping memory\n");
 		return -EBUSY;
 	}
 
-	info->clk = devm_clk_get(&pdev->dev, NULL);
-	if (IS_ERR(info->clk)) {
+	st->clk = devm_clk_get(&pdev->dev, NULL);
+	if (IS_ERR(st->clk)) {
 		dev_err(&pdev->dev, "failed getting clock\n");
-		return PTR_ERR(info->clk);
+		return PTR_ERR(st->clk);
 	}
 
 	irq = platform_get_irq(pdev, 0);
@@ -170,7 +170,7 @@ static int lpc32xx_adc_probe(struct platform_device *pdev)
 	}
 
 	retval = devm_request_irq(&pdev->dev, irq, lpc32xx_adc_isr, 0,
-				  LPC32XXAD_NAME, info);
+				  LPC32XXAD_NAME, st);
 	if (retval < 0) {
 		dev_err(&pdev->dev, "failed requesting interrupt\n");
 		return retval;
@@ -178,7 +178,7 @@ static int lpc32xx_adc_probe(struct platform_device *pdev)
 
 	platform_set_drvdata(pdev, iodev);
 
-	init_completion(&info->completion);
+	init_completion(&st->completion);
 
 	iodev->name = LPC32XXAD_NAME;
 	iodev->dev.parent = &pdev->dev;
-- 
2.11.1


^ permalink raw reply related	[flat|nested] 7+ messages in thread

* [PATCH 3/3] staging:iio:adc:lpc32xx Move out of staging.
  2017-02-05 13:06 [PATCH 0/3] staging:iio:adc:lpc32xx cleanup and staging graduation Jonathan Cameron
  2017-02-05 13:06 ` [PATCH 1/3] staging:iio:adc:lpc32xx Apply consistent prefix to local defines Jonathan Cameron
  2017-02-05 13:06 ` [PATCH 2/3] staging:iio:adc:lpc32xx rename local state structure to _state Jonathan Cameron
@ 2017-02-05 13:07 ` Jonathan Cameron
  2017-02-11 11:22   ` Jonathan Cameron
  2 siblings, 1 reply; 7+ messages in thread
From: Jonathan Cameron @ 2017-02-05 13:07 UTC (permalink / raw)
  To: linux-iio; +Cc: Roland Stigge, Jonathan Cameron

There are a few more little cleanups that could be done on this driver, but
I don't think any are sufficient to justify not moving it out of staging.

It's a very simple driver (presumably for a simple part) so not much that can
go wrong.  I think it was only ever in staging because that's where IIO was
as a whole at the time and then we forgot about it!

Signed-off-by: Jonathan Cameron <jic23@kernel.org>
Cc: Roland Stigge <stigge@antcom.de>
---
 drivers/iio/adc/Kconfig               |  12 ++
 drivers/iio/adc/Makefile              |   1 +
 drivers/iio/adc/lpc32xx_adc.c         | 219 ++++++++++++++++++++++++++++++++++
 drivers/staging/iio/adc/Kconfig       |  12 --
 drivers/staging/iio/adc/Makefile      |   1 -
 drivers/staging/iio/adc/lpc32xx_adc.c | 219 ----------------------------------
 6 files changed, 232 insertions(+), 232 deletions(-)

diff --git a/drivers/iio/adc/Kconfig b/drivers/iio/adc/Kconfig
index 789a5fb7c0be..d777a972586d 100644
--- a/drivers/iio/adc/Kconfig
+++ b/drivers/iio/adc/Kconfig
@@ -305,6 +305,18 @@ config LPC18XX_ADC
 	  To compile this driver as a module, choose M here: the module will be
 	  called lpc18xx_adc.
 
+config LPC32XX_ADC
+	tristate "NXP LPC32XX ADC"
+	depends on ARCH_LPC32XX || COMPILE_TEST
+	depends on HAS_IOMEM
+	help
+	  Say yes here to build support for the integrated ADC inside the
+	  LPC32XX SoC. Note that this feature uses the same hardware as the
+	  touchscreen driver, so you should either select only one of the two
+	  drivers (lpc32xx_adc or lpc32xx_ts) or, in the OpenFirmware case,
+	  activate only one via device tree selection.  Provides direct access
+	  via sysfs.
+
 config LTC2485
 	tristate "Linear Technology LTC2485 ADC driver"
 	depends on I2C
diff --git a/drivers/iio/adc/Makefile b/drivers/iio/adc/Makefile
index 19e48af43b97..b11bb5767543 100644
--- a/drivers/iio/adc/Makefile
+++ b/drivers/iio/adc/Makefile
@@ -30,6 +30,7 @@ obj-$(CONFIG_IMX7D_ADC) += imx7d_adc.o
 obj-$(CONFIG_INA2XX_ADC) += ina2xx-adc.o
 obj-$(CONFIG_LP8788_ADC) += lp8788_adc.o
 obj-$(CONFIG_LPC18XX_ADC) += lpc18xx_adc.o
+obj-$(CONFIG_LPC32XX_ADC) += lpc32xx_adc.o
 obj-$(CONFIG_LTC2485) += ltc2485.o
 obj-$(CONFIG_MAX1027) += max1027.o
 obj-$(CONFIG_MAX11100) += max11100.o
diff --git a/drivers/iio/adc/lpc32xx_adc.c b/drivers/iio/adc/lpc32xx_adc.c
new file mode 100644
index 000000000000..0de709b4288b
--- /dev/null
+++ b/drivers/iio/adc/lpc32xx_adc.c
@@ -0,0 +1,219 @@
+/*
+ *  lpc32xx_adc.c - Support for ADC in LPC32XX
+ *
+ *  3-channel, 10-bit ADC
+ *
+ *  Copyright (C) 2011, 2012 Roland Stigge <stigge@antcom.de>
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#include <linux/module.h>
+#include <linux/platform_device.h>
+#include <linux/interrupt.h>
+#include <linux/device.h>
+#include <linux/kernel.h>
+#include <linux/slab.h>
+#include <linux/io.h>
+#include <linux/clk.h>
+#include <linux/err.h>
+#include <linux/completion.h>
+#include <linux/of.h>
+
+#include <linux/iio/iio.h>
+#include <linux/iio/sysfs.h>
+
+/*
+ * LPC32XX registers definitions
+ */
+#define LPC32XXAD_SELECT(x)	((x) + 0x04)
+#define LPC32XXAD_CTRL(x)	((x) + 0x08)
+#define LPC32XXAD_VALUE(x)	((x) + 0x48)
+
+/* Bit definitions for LPC32XXAD_SELECT: */
+/* constant, always write this value! */
+#define LPC32XXAD_REFm         0x00000200
+/* constant, always write this value! */
+#define LPC32XXAD_REFp		0x00000080
+ /* multiple of this is the channel number: 0, 1, 2 */
+#define LPC32XXAD_IN		0x00000010
+/* constant, always write this value! */
+#define LPC32XXAD_INTERNAL	0x00000004
+
+/* Bit definitions for LPC32XXAD_CTRL: */
+#define LPC32XXAD_STROBE	0x00000002
+#define LPC32XXAD_PDN_CTRL	0x00000004
+
+/* Bit definitions for LPC32XXAD_VALUE: */
+#define LPC32XXAD_VALUE_MASK	0x000003FF
+
+#define LPC32XXAD_NAME "lpc32xx-adc"
+
+struct lpc32xx_adc_state {
+	void __iomem *adc_base;
+	struct clk *clk;
+	struct completion completion;
+
+	u32 value;
+};
+
+static int lpc32xx_read_raw(struct iio_dev *indio_dev,
+			    struct iio_chan_spec const *chan,
+			    int *val,
+			    int *val2,
+			    long mask)
+{
+	struct lpc32xx_adc_state *st = iio_priv(indio_dev);
+
+	if (mask == IIO_CHAN_INFO_RAW) {
+		mutex_lock(&indio_dev->mlock);
+		clk_prepare_enable(st->clk);
+		/* Measurement setup */
+		__raw_writel(LPC32XXAD_INTERNAL | (chan->address) |
+			     LPC32XXAD_REFp | LPC32XXAD_REFm,
+			     LPC32XXAD_SELECT(st->adc_base));
+		/* Trigger conversion */
+		__raw_writel(LPC32XXAD_PDN_CTRL | LPC32XXAD_STROBE,
+			     LPC32XXAD_CTRL(st->adc_base));
+		wait_for_completion(&st->completion); /* set by ISR */
+		clk_disable_unprepare(st->clk);
+		*val = st->value;
+		mutex_unlock(&indio_dev->mlock);
+
+		return IIO_VAL_INT;
+	}
+
+	return -EINVAL;
+}
+
+static const struct iio_info lpc32xx_adc_iio_info = {
+	.read_raw = &lpc32xx_read_raw,
+	.driver_module = THIS_MODULE,
+};
+
+#define LPC32XX_ADC_CHANNEL(_index) {			\
+	.type = IIO_VOLTAGE,				\
+	.indexed = 1,					\
+	.channel = _index,				\
+	.info_mask_separate = BIT(IIO_CHAN_INFO_RAW),	\
+	.address = LPC32XXAD_IN * _index,		\
+	.scan_index = _index,				\
+}
+
+static const struct iio_chan_spec lpc32xx_adc_iio_channels[] = {
+	LPC32XX_ADC_CHANNEL(0),
+	LPC32XX_ADC_CHANNEL(1),
+	LPC32XX_ADC_CHANNEL(2),
+};
+
+static irqreturn_t lpc32xx_adc_isr(int irq, void *dev_id)
+{
+	struct lpc32xx_adc_state *st = dev_id;
+
+	/* Read value and clear irq */
+	st->value = __raw_readl(LPC32XXAD_VALUE(st->adc_base)) &
+		LPC32XXAD_VALUE_MASK;
+	complete(&st->completion);
+
+	return IRQ_HANDLED;
+}
+
+static int lpc32xx_adc_probe(struct platform_device *pdev)
+{
+	struct lpc32xx_adc_state *st = NULL;
+	struct resource *res;
+	int retval = -ENODEV;
+	struct iio_dev *iodev = NULL;
+	int irq;
+
+	res = platform_get_resource(pdev, IORESOURCE_MEM, 0);
+	if (!res) {
+		dev_err(&pdev->dev, "failed to get platform I/O memory\n");
+		return -ENXIO;
+	}
+
+	iodev = devm_iio_device_alloc(&pdev->dev, sizeof(*st));
+	if (!iodev)
+		return -ENOMEM;
+
+	st = iio_priv(iodev);
+
+	st->adc_base = devm_ioremap(&pdev->dev, res->start,
+				    resource_size(res));
+	if (!st->adc_base) {
+		dev_err(&pdev->dev, "failed mapping memory\n");
+		return -EBUSY;
+	}
+
+	st->clk = devm_clk_get(&pdev->dev, NULL);
+	if (IS_ERR(st->clk)) {
+		dev_err(&pdev->dev, "failed getting clock\n");
+		return PTR_ERR(st->clk);
+	}
+
+	irq = platform_get_irq(pdev, 0);
+	if (irq <= 0) {
+		dev_err(&pdev->dev, "failed getting interrupt resource\n");
+		return -ENXIO;
+	}
+
+	retval = devm_request_irq(&pdev->dev, irq, lpc32xx_adc_isr, 0,
+				  LPC32XXAD_NAME, st);
+	if (retval < 0) {
+		dev_err(&pdev->dev, "failed requesting interrupt\n");
+		return retval;
+	}
+
+	platform_set_drvdata(pdev, iodev);
+
+	init_completion(&st->completion);
+
+	iodev->name = LPC32XXAD_NAME;
+	iodev->dev.parent = &pdev->dev;
+	iodev->info = &lpc32xx_adc_iio_info;
+	iodev->modes = INDIO_DIRECT_MODE;
+	iodev->channels = lpc32xx_adc_iio_channels;
+	iodev->num_channels = ARRAY_SIZE(lpc32xx_adc_iio_channels);
+
+	retval = devm_iio_device_register(&pdev->dev, iodev);
+	if (retval)
+		return retval;
+
+	dev_info(&pdev->dev, "LPC32XX ADC driver loaded, IRQ %d\n", irq);
+
+	return 0;
+}
+
+#ifdef CONFIG_OF
+static const struct of_device_id lpc32xx_adc_match[] = {
+	{ .compatible = "nxp,lpc3220-adc" },
+	{},
+};
+MODULE_DEVICE_TABLE(of, lpc32xx_adc_match);
+#endif
+
+static struct platform_driver lpc32xx_adc_driver = {
+	.probe		= lpc32xx_adc_probe,
+	.driver		= {
+		.name	= LPC32XXAD_NAME,
+		.of_match_table = of_match_ptr(lpc32xx_adc_match),
+	},
+};
+
+module_platform_driver(lpc32xx_adc_driver);
+
+MODULE_AUTHOR("Roland Stigge <stigge@antcom.de>");
+MODULE_DESCRIPTION("LPC32XX ADC driver");
+MODULE_LICENSE("GPL");
diff --git a/drivers/staging/iio/adc/Kconfig b/drivers/staging/iio/adc/Kconfig
index 0ad5c44042b2..e17efb03bac0 100644
--- a/drivers/staging/iio/adc/Kconfig
+++ b/drivers/staging/iio/adc/Kconfig
@@ -80,16 +80,4 @@ config AD7280
 	  To compile this driver as a module, choose M here: the
 	  module will be called ad7280a
 
-config LPC32XX_ADC
-	tristate "NXP LPC32XX ADC"
-	depends on ARCH_LPC32XX || COMPILE_TEST
-	depends on HAS_IOMEM
-	help
-	  Say yes here to build support for the integrated ADC inside the
-	  LPC32XX SoC. Note that this feature uses the same hardware as the
-	  touchscreen driver, so you should either select only one of the two
-	  drivers (lpc32xx_adc or lpc32xx_ts) or, in the OpenFirmware case,
-	  activate only one via device tree selection.  Provides direct access
-	  via sysfs.
-
 endmenu
diff --git a/drivers/staging/iio/adc/Makefile b/drivers/staging/iio/adc/Makefile
index e7098dedeb75..bf18bdd7c99d 100644
--- a/drivers/staging/iio/adc/Makefile
+++ b/drivers/staging/iio/adc/Makefile
@@ -10,4 +10,3 @@ obj-$(CONFIG_AD7780) += ad7780.o
 obj-$(CONFIG_AD7816) += ad7816.o
 obj-$(CONFIG_AD7192) += ad7192.o
 obj-$(CONFIG_AD7280) += ad7280a.o
-obj-$(CONFIG_LPC32XX_ADC) += lpc32xx_adc.o
diff --git a/drivers/staging/iio/adc/lpc32xx_adc.c b/drivers/staging/iio/adc/lpc32xx_adc.c
deleted file mode 100644
index 0de709b4288b..000000000000
--- a/drivers/staging/iio/adc/lpc32xx_adc.c
+++ /dev/null
@@ -1,219 +0,0 @@
-/*
- *  lpc32xx_adc.c - Support for ADC in LPC32XX
- *
- *  3-channel, 10-bit ADC
- *
- *  Copyright (C) 2011, 2012 Roland Stigge <stigge@antcom.de>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-#include <linux/module.h>
-#include <linux/platform_device.h>
-#include <linux/interrupt.h>
-#include <linux/device.h>
-#include <linux/kernel.h>
-#include <linux/slab.h>
-#include <linux/io.h>
-#include <linux/clk.h>
-#include <linux/err.h>
-#include <linux/completion.h>
-#include <linux/of.h>
-
-#include <linux/iio/iio.h>
-#include <linux/iio/sysfs.h>
-
-/*
- * LPC32XX registers definitions
- */
-#define LPC32XXAD_SELECT(x)	((x) + 0x04)
-#define LPC32XXAD_CTRL(x)	((x) + 0x08)
-#define LPC32XXAD_VALUE(x)	((x) + 0x48)
-
-/* Bit definitions for LPC32XXAD_SELECT: */
-/* constant, always write this value! */
-#define LPC32XXAD_REFm         0x00000200
-/* constant, always write this value! */
-#define LPC32XXAD_REFp		0x00000080
- /* multiple of this is the channel number: 0, 1, 2 */
-#define LPC32XXAD_IN		0x00000010
-/* constant, always write this value! */
-#define LPC32XXAD_INTERNAL	0x00000004
-
-/* Bit definitions for LPC32XXAD_CTRL: */
-#define LPC32XXAD_STROBE	0x00000002
-#define LPC32XXAD_PDN_CTRL	0x00000004
-
-/* Bit definitions for LPC32XXAD_VALUE: */
-#define LPC32XXAD_VALUE_MASK	0x000003FF
-
-#define LPC32XXAD_NAME "lpc32xx-adc"
-
-struct lpc32xx_adc_state {
-	void __iomem *adc_base;
-	struct clk *clk;
-	struct completion completion;
-
-	u32 value;
-};
-
-static int lpc32xx_read_raw(struct iio_dev *indio_dev,
-			    struct iio_chan_spec const *chan,
-			    int *val,
-			    int *val2,
-			    long mask)
-{
-	struct lpc32xx_adc_state *st = iio_priv(indio_dev);
-
-	if (mask == IIO_CHAN_INFO_RAW) {
-		mutex_lock(&indio_dev->mlock);
-		clk_prepare_enable(st->clk);
-		/* Measurement setup */
-		__raw_writel(LPC32XXAD_INTERNAL | (chan->address) |
-			     LPC32XXAD_REFp | LPC32XXAD_REFm,
-			     LPC32XXAD_SELECT(st->adc_base));
-		/* Trigger conversion */
-		__raw_writel(LPC32XXAD_PDN_CTRL | LPC32XXAD_STROBE,
-			     LPC32XXAD_CTRL(st->adc_base));
-		wait_for_completion(&st->completion); /* set by ISR */
-		clk_disable_unprepare(st->clk);
-		*val = st->value;
-		mutex_unlock(&indio_dev->mlock);
-
-		return IIO_VAL_INT;
-	}
-
-	return -EINVAL;
-}
-
-static const struct iio_info lpc32xx_adc_iio_info = {
-	.read_raw = &lpc32xx_read_raw,
-	.driver_module = THIS_MODULE,
-};
-
-#define LPC32XX_ADC_CHANNEL(_index) {			\
-	.type = IIO_VOLTAGE,				\
-	.indexed = 1,					\
-	.channel = _index,				\
-	.info_mask_separate = BIT(IIO_CHAN_INFO_RAW),	\
-	.address = LPC32XXAD_IN * _index,		\
-	.scan_index = _index,				\
-}
-
-static const struct iio_chan_spec lpc32xx_adc_iio_channels[] = {
-	LPC32XX_ADC_CHANNEL(0),
-	LPC32XX_ADC_CHANNEL(1),
-	LPC32XX_ADC_CHANNEL(2),
-};
-
-static irqreturn_t lpc32xx_adc_isr(int irq, void *dev_id)
-{
-	struct lpc32xx_adc_state *st = dev_id;
-
-	/* Read value and clear irq */
-	st->value = __raw_readl(LPC32XXAD_VALUE(st->adc_base)) &
-		LPC32XXAD_VALUE_MASK;
-	complete(&st->completion);
-
-	return IRQ_HANDLED;
-}
-
-static int lpc32xx_adc_probe(struct platform_device *pdev)
-{
-	struct lpc32xx_adc_state *st = NULL;
-	struct resource *res;
-	int retval = -ENODEV;
-	struct iio_dev *iodev = NULL;
-	int irq;
-
-	res = platform_get_resource(pdev, IORESOURCE_MEM, 0);
-	if (!res) {
-		dev_err(&pdev->dev, "failed to get platform I/O memory\n");
-		return -ENXIO;
-	}
-
-	iodev = devm_iio_device_alloc(&pdev->dev, sizeof(*st));
-	if (!iodev)
-		return -ENOMEM;
-
-	st = iio_priv(iodev);
-
-	st->adc_base = devm_ioremap(&pdev->dev, res->start,
-				    resource_size(res));
-	if (!st->adc_base) {
-		dev_err(&pdev->dev, "failed mapping memory\n");
-		return -EBUSY;
-	}
-
-	st->clk = devm_clk_get(&pdev->dev, NULL);
-	if (IS_ERR(st->clk)) {
-		dev_err(&pdev->dev, "failed getting clock\n");
-		return PTR_ERR(st->clk);
-	}
-
-	irq = platform_get_irq(pdev, 0);
-	if (irq <= 0) {
-		dev_err(&pdev->dev, "failed getting interrupt resource\n");
-		return -ENXIO;
-	}
-
-	retval = devm_request_irq(&pdev->dev, irq, lpc32xx_adc_isr, 0,
-				  LPC32XXAD_NAME, st);
-	if (retval < 0) {
-		dev_err(&pdev->dev, "failed requesting interrupt\n");
-		return retval;
-	}
-
-	platform_set_drvdata(pdev, iodev);
-
-	init_completion(&st->completion);
-
-	iodev->name = LPC32XXAD_NAME;
-	iodev->dev.parent = &pdev->dev;
-	iodev->info = &lpc32xx_adc_iio_info;
-	iodev->modes = INDIO_DIRECT_MODE;
-	iodev->channels = lpc32xx_adc_iio_channels;
-	iodev->num_channels = ARRAY_SIZE(lpc32xx_adc_iio_channels);
-
-	retval = devm_iio_device_register(&pdev->dev, iodev);
-	if (retval)
-		return retval;
-
-	dev_info(&pdev->dev, "LPC32XX ADC driver loaded, IRQ %d\n", irq);
-
-	return 0;
-}
-
-#ifdef CONFIG_OF
-static const struct of_device_id lpc32xx_adc_match[] = {
-	{ .compatible = "nxp,lpc3220-adc" },
-	{},
-};
-MODULE_DEVICE_TABLE(of, lpc32xx_adc_match);
-#endif
-
-static struct platform_driver lpc32xx_adc_driver = {
-	.probe		= lpc32xx_adc_probe,
-	.driver		= {
-		.name	= LPC32XXAD_NAME,
-		.of_match_table = of_match_ptr(lpc32xx_adc_match),
-	},
-};
-
-module_platform_driver(lpc32xx_adc_driver);
-
-MODULE_AUTHOR("Roland Stigge <stigge@antcom.de>");
-MODULE_DESCRIPTION("LPC32XX ADC driver");
-MODULE_LICENSE("GPL");
diff --git a/drivers/staging/iio/adc/lpc32xx_adc.c b/drivers/staging/iio/adc/lpc32xx_adc.c
index b51f237cd817..5d13ff008a39 100644
--- a/drivers/staging/iio/adc/lpc32xx_adc.c
+++ b/drivers/staging/iio/adc/lpc32xx_adc.c
@@ -38,25 +38,28 @@
 /*
  * LPC32XX registers definitions
  */
-#define LPC32XX_ADC_SELECT(x)	((x) + 0x04)
-#define LPC32XX_ADC_CTRL(x)	((x) + 0x08)
-#define LPC32XX_ADC_VALUE(x)	((x) + 0x48)
+#define LPC32XXAD_SELECT(x)	((x) + 0x04)
+#define LPC32XXAD_CTRL(x)	((x) + 0x08)
+#define LPC32XXAD_VALUE(x)	((x) + 0x48)
 
-/* Bit definitions for LPC32XX_ADC_SELECT: */
-#define AD_REFm         0x00000200 /* constant, always write this value! */
-#define AD_REFp		0x00000080 /* constant, always write this value! */
-#define AD_IN		0x00000010 /* multiple of this is the */
-				   /* channel number: 0, 1, 2 */
-#define AD_INTERNAL	0x00000004 /* constant, always write this value! */
+/* Bit definitions for LPC32XXAD_SELECT: */
+/* constant, always write this value! */
+#define LPC32XXAD_REFm         0x00000200
+/* constant, always write this value! */
+#define LPC32XXAD_REFp		0x00000080
+ /* multiple of this is the channel number: 0, 1, 2 */
+#define LPC32XXAD_IN		0x00000010
+/* constant, always write this value! */
+#define LPC32XXAD_INTERNAL	0x00000004
 
 /* Bit definitions for LPC32XX_ADC_CTRL: */
 #define AD_STROBE	0x00000002
 #define AD_PDN_CTRL	0x00000004
 
 /* Bit definitions for LPC32XX_ADC_VALUE: */
 #define ADC_VALUE_MASK	0x000003FF
 
-#define MOD_NAME "lpc32xx-adc"
+#define LPC32XXAD_NAME "lpc32xx-adc"
 
 struct lpc32xx_adc_info {
 	void __iomem *adc_base;
@@ -78,11 +81,12 @@ static int lpc32xx_read_raw(struct iio_dev *indio_dev,
 		mutex_lock(&indio_dev->mlock);
 		clk_prepare_enable(info->clk);
 		/* Measurement setup */
-		__raw_writel(AD_INTERNAL | (chan->address) | AD_REFp | AD_REFm,
-			     LPC32XX_ADC_SELECT(info->adc_base));
+		__raw_writel(LPC32XXAD_INTERNAL | (chan->address) |
+			     LPC32XXAD_REFp | LPC32XXAD_REFm,
+			     LPC32XXAD_SELECT(info->adc_base));
 		/* Trigger conversion */
-		__raw_writel(AD_PDN_CTRL | AD_STROBE,
-			     LPC32XX_ADC_CTRL(info->adc_base));
+		__raw_writel(LPC32XXAD_PDN_CTRL | LPC32XXAD_STROBE,
+			     LPC32XXAD_CTRL(info->adc_base));
 		wait_for_completion(&info->completion); /* set by ISR */
 		clk_disable_unprepare(info->clk);
 		*val = info->value;
@@ -104,7 +108,7 @@ static const struct iio_info lpc32xx_adc_iio_info = {
 	.indexed = 1,					\
 	.channel = _index,				\
 	.info_mask_separate = BIT(IIO_CHAN_INFO_RAW),	\
-	.address = AD_IN * _index,			\
+	.address = LPC32XXAD_IN * _index,		\
 	.scan_index = _index,				\
 }
 
@@ -119,8 +123,8 @@ static irqreturn_t lpc32xx_adc_isr(int irq, void *dev_id)
 	struct lpc32xx_adc_info *info = dev_id;
 
 	/* Read value and clear irq */
-	info->value = __raw_readl(LPC32XX_ADC_VALUE(info->adc_base)) &
-				ADC_VALUE_MASK;
+	info->value = __raw_readl(LPC32XXAD_VALUE(info->adc_base)) &
+				LPC32XXAD_VALUE_MASK;
 	complete(&info->completion);
 
 	return IRQ_HANDLED;
@@ -166,7 +170,7 @@ static int lpc32xx_adc_probe(struct platform_device *pdev)
 	}
 
 	retval = devm_request_irq(&pdev->dev, irq, lpc32xx_adc_isr, 0,
-				  MOD_NAME, info);
+				  LPC32XXAD_NAME, info);
 	if (retval < 0) {
 		dev_err(&pdev->dev, "failed requesting interrupt\n");
 		return retval;
@@ -176,7 +180,7 @@ static int lpc32xx_adc_probe(struct platform_device *pdev)
 
 	init_completion(&info->completion);
 
-	iodev->name = MOD_NAME;
+	iodev->name = LPC32XXAD_NAME;
 	iodev->dev.parent = &pdev->dev;
 	iodev->info = &lpc32xx_adc_iio_info;
 	iodev->modes = INDIO_DIRECT_MODE;
@@ -203,7 +207,7 @@ MODULE_DEVICE_TABLE(of, lpc32xx_adc_match);
 static struct platform_driver lpc32xx_adc_driver = {
 	.probe		= lpc32xx_adc_probe,
 	.driver		= {
-		.name	= MOD_NAME,
+		.name	= LPC32XXAD_NAME,
 		.of_match_table = of_match_ptr(lpc32xx_adc_match),
 	},
 };
@@ -38,25 +38,28 @@
 
-/* Bit definitions for LPC32XX_ADC_CTRL: */
-#define AD_STROBE	0x00000002
-#define AD_PDN_CTRL	0x00000004
+/* Bit definitions for LPC32XXAD_CTRL: */
+#define LPC32XXAD_STROBE	0x00000002
+#define LPC32XXAD_PDN_CTRL	0x00000004
 
@@ -38,25 +38,28 @@
 
-/* Bit definitions for LPC32XX_ADC_VALUE: */
-#define ADC_VALUE_MASK	0x000003FF
+/* Bit definitions for LPC32XXAD_VALUE: */
+#define LPC32XXAD_VALUE_MASK	0x000003FF
 
-- 
2.11.1


^ permalink raw reply related	[flat|nested] 7+ messages in thread

* Re: [PATCH 1/3] staging:iio:adc:lpc32xx Apply consistent prefix to local defines
  2017-02-05 13:06 ` [PATCH 1/3] staging:iio:adc:lpc32xx Apply consistent prefix to local defines Jonathan Cameron
@ 2017-02-11 11:20   ` Jonathan Cameron
  0 siblings, 0 replies; 7+ messages in thread
From: Jonathan Cameron @ 2017-02-11 11:20 UTC (permalink / raw)
  To: linux-iio; +Cc: Roland Stigge

On 05/02/17 13:06, Jonathan Cameron wrote:
> There was a bit of a random mixture going on here so change all prefixes
> to LPC32XXAD_
> 
> Signed-off-by: Jonathan Cameron <jic23@kernel.org>
Applied to the togreg branch of iio.git.
Obviously I'd love to get a review on these if anyone has the time.

If not they are straight forward enough really I'll take them anyway ;)

Plenty of time to do a review as I'll not be sending a pull request for
a couple of weeks due to the upcoming merge window.

I just didn't want to forget them!

Jonathan

> ---
>  drivers/staging/iio/adc/lpc32xx_adc.c | 54 +++++++++++++++++++----------------
>  1 file changed, 29 insertions(+), 25 deletions(-)
> 
> diff --git a/drivers/staging/iio/adc/lpc32xx_adc.c b/drivers/staging/iio/adc/lpc32xx_adc.c
> index b51f237cd817..5d13ff008a39 100644
> --- a/drivers/staging/iio/adc/lpc32xx_adc.c
> +++ b/drivers/staging/iio/adc/lpc32xx_adc.c
> @@ -38,25 +38,28 @@
>  /*
>   * LPC32XX registers definitions
>   */
> -#define LPC32XX_ADC_SELECT(x)	((x) + 0x04)
> -#define LPC32XX_ADC_CTRL(x)	((x) + 0x08)
> -#define LPC32XX_ADC_VALUE(x)	((x) + 0x48)
> +#define LPC32XXAD_SELECT(x)	((x) + 0x04)
> +#define LPC32XXAD_CTRL(x)	((x) + 0x08)
> +#define LPC32XXAD_VALUE(x)	((x) + 0x48)
>  
> -/* Bit definitions for LPC32XX_ADC_SELECT: */
> -#define AD_REFm         0x00000200 /* constant, always write this value! */
> -#define AD_REFp		0x00000080 /* constant, always write this value! */
> -#define AD_IN		0x00000010 /* multiple of this is the */
> -				   /* channel number: 0, 1, 2 */
> -#define AD_INTERNAL	0x00000004 /* constant, always write this value! */
> +/* Bit definitions for LPC32XXAD_SELECT: */
> +/* constant, always write this value! */
> +#define LPC32XXAD_REFm         0x00000200
> +/* constant, always write this value! */
> +#define LPC32XXAD_REFp		0x00000080
> + /* multiple of this is the channel number: 0, 1, 2 */
> +#define LPC32XXAD_IN		0x00000010
> +/* constant, always write this value! */
> +#define LPC32XXAD_INTERNAL	0x00000004
>  
> -/* Bit definitions for LPC32XX_ADC_CTRL: */
> -#define AD_STROBE	0x00000002
> -#define AD_PDN_CTRL	0x00000004
> +/* Bit definitions for LPC32XXAD_CTRL: */
> +#define LPC32XXAD_STROBE	0x00000002
> +#define LPC32XXAD_PDN_CTRL	0x00000004
>  
> -/* Bit definitions for LPC32XX_ADC_VALUE: */
> -#define ADC_VALUE_MASK	0x000003FF
> +/* Bit definitions for LPC32XXAD_VALUE: */
> +#define LPC32XXAD_VALUE_MASK	0x000003FF
>  
> -#define MOD_NAME "lpc32xx-adc"
> +#define LPC32XXAD_NAME "lpc32xx-adc"
>  
>  struct lpc32xx_adc_info {
>  	void __iomem *adc_base;
> @@ -78,11 +81,12 @@ static int lpc32xx_read_raw(struct iio_dev *indio_dev,
>  		mutex_lock(&indio_dev->mlock);
>  		clk_prepare_enable(info->clk);
>  		/* Measurement setup */
> -		__raw_writel(AD_INTERNAL | (chan->address) | AD_REFp | AD_REFm,
> -			     LPC32XX_ADC_SELECT(info->adc_base));
> +		__raw_writel(LPC32XXAD_INTERNAL | (chan->address) |
> +			     LPC32XXAD_REFp | LPC32XXAD_REFm,
> +			     LPC32XXAD_SELECT(info->adc_base));
>  		/* Trigger conversion */
> -		__raw_writel(AD_PDN_CTRL | AD_STROBE,
> -			     LPC32XX_ADC_CTRL(info->adc_base));
> +		__raw_writel(LPC32XXAD_PDN_CTRL | LPC32XXAD_STROBE,
> +			     LPC32XXAD_CTRL(info->adc_base));
>  		wait_for_completion(&info->completion); /* set by ISR */
>  		clk_disable_unprepare(info->clk);
>  		*val = info->value;
> @@ -104,7 +108,7 @@ static const struct iio_info lpc32xx_adc_iio_info = {
>  	.indexed = 1,					\
>  	.channel = _index,				\
>  	.info_mask_separate = BIT(IIO_CHAN_INFO_RAW),	\
> -	.address = AD_IN * _index,			\
> +	.address = LPC32XXAD_IN * _index,		\
>  	.scan_index = _index,				\
>  }
>  
> @@ -119,8 +123,8 @@ static irqreturn_t lpc32xx_adc_isr(int irq, void *dev_id)
>  	struct lpc32xx_adc_info *info = dev_id;
>  
>  	/* Read value and clear irq */
> -	info->value = __raw_readl(LPC32XX_ADC_VALUE(info->adc_base)) &
> -				ADC_VALUE_MASK;
> +	info->value = __raw_readl(LPC32XXAD_VALUE(info->adc_base)) &
> +				LPC32XXAD_VALUE_MASK;
>  	complete(&info->completion);
>  
>  	return IRQ_HANDLED;
> @@ -166,7 +170,7 @@ static int lpc32xx_adc_probe(struct platform_device *pdev)
>  	}
>  
>  	retval = devm_request_irq(&pdev->dev, irq, lpc32xx_adc_isr, 0,
> -				  MOD_NAME, info);
> +				  LPC32XXAD_NAME, info);
>  	if (retval < 0) {
>  		dev_err(&pdev->dev, "failed requesting interrupt\n");
>  		return retval;
> @@ -176,7 +180,7 @@ static int lpc32xx_adc_probe(struct platform_device *pdev)
>  
>  	init_completion(&info->completion);
>  
> -	iodev->name = MOD_NAME;
> +	iodev->name = LPC32XXAD_NAME;
>  	iodev->dev.parent = &pdev->dev;
>  	iodev->info = &lpc32xx_adc_iio_info;
>  	iodev->modes = INDIO_DIRECT_MODE;
> @@ -203,7 +207,7 @@ MODULE_DEVICE_TABLE(of, lpc32xx_adc_match);
>  static struct platform_driver lpc32xx_adc_driver = {
>  	.probe		= lpc32xx_adc_probe,
>  	.driver		= {
> -		.name	= MOD_NAME,
> +		.name	= LPC32XXAD_NAME,
>  		.of_match_table = of_match_ptr(lpc32xx_adc_match),
>  	},
>  };
> 


^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [PATCH 2/3] staging:iio:adc:lpc32xx rename local state structure to _state
  2017-02-05 13:06 ` [PATCH 2/3] staging:iio:adc:lpc32xx rename local state structure to _state Jonathan Cameron
@ 2017-02-11 11:21   ` Jonathan Cameron
  0 siblings, 0 replies; 7+ messages in thread
From: Jonathan Cameron @ 2017-02-11 11:21 UTC (permalink / raw)
  To: linux-iio; +Cc: Roland Stigge

On 05/02/17 13:06, Jonathan Cameron wrote:
> Previously it was called _info with instances as info.  This caused some
> confusion against the info structure that are used in the core of IIO.
> 
> Since this driver was written it's become a fairly strong convention to
> use _state and st for instances so change to that.
> 
> Signed-off-by: Jonathan Cameron <jic23@kernel.org>
Applied to the togreg branch of iio.git and pushed out as testing.

Thanks,

Jonathan
> ---
>  drivers/staging/iio/adc/lpc32xx_adc.c | 46 +++++++++++++++++------------------
>  1 file changed, 23 insertions(+), 23 deletions(-)
> 
> diff --git a/drivers/staging/iio/adc/lpc32xx_adc.c b/drivers/staging/iio/adc/lpc32xx_adc.c
> index 5d13ff008a39..0de709b4288b 100644
> --- a/drivers/staging/iio/adc/lpc32xx_adc.c
> +++ b/drivers/staging/iio/adc/lpc32xx_adc.c
> @@ -61,7 +61,7 @@
>  
>  #define LPC32XXAD_NAME "lpc32xx-adc"
>  
> -struct lpc32xx_adc_info {
> +struct lpc32xx_adc_state {
>  	void __iomem *adc_base;
>  	struct clk *clk;
>  	struct completion completion;
> @@ -75,21 +75,21 @@ static int lpc32xx_read_raw(struct iio_dev *indio_dev,
>  			    int *val2,
>  			    long mask)
>  {
> -	struct lpc32xx_adc_info *info = iio_priv(indio_dev);
> +	struct lpc32xx_adc_state *st = iio_priv(indio_dev);
>  
>  	if (mask == IIO_CHAN_INFO_RAW) {
>  		mutex_lock(&indio_dev->mlock);
> -		clk_prepare_enable(info->clk);
> +		clk_prepare_enable(st->clk);
>  		/* Measurement setup */
>  		__raw_writel(LPC32XXAD_INTERNAL | (chan->address) |
>  			     LPC32XXAD_REFp | LPC32XXAD_REFm,
> -			     LPC32XXAD_SELECT(info->adc_base));
> +			     LPC32XXAD_SELECT(st->adc_base));
>  		/* Trigger conversion */
>  		__raw_writel(LPC32XXAD_PDN_CTRL | LPC32XXAD_STROBE,
> -			     LPC32XXAD_CTRL(info->adc_base));
> -		wait_for_completion(&info->completion); /* set by ISR */
> -		clk_disable_unprepare(info->clk);
> -		*val = info->value;
> +			     LPC32XXAD_CTRL(st->adc_base));
> +		wait_for_completion(&st->completion); /* set by ISR */
> +		clk_disable_unprepare(st->clk);
> +		*val = st->value;
>  		mutex_unlock(&indio_dev->mlock);
>  
>  		return IIO_VAL_INT;
> @@ -120,19 +120,19 @@ static const struct iio_chan_spec lpc32xx_adc_iio_channels[] = {
>  
>  static irqreturn_t lpc32xx_adc_isr(int irq, void *dev_id)
>  {
> -	struct lpc32xx_adc_info *info = dev_id;
> +	struct lpc32xx_adc_state *st = dev_id;
>  
>  	/* Read value and clear irq */
> -	info->value = __raw_readl(LPC32XXAD_VALUE(info->adc_base)) &
> -				LPC32XXAD_VALUE_MASK;
> -	complete(&info->completion);
> +	st->value = __raw_readl(LPC32XXAD_VALUE(st->adc_base)) &
> +		LPC32XXAD_VALUE_MASK;
> +	complete(&st->completion);
>  
>  	return IRQ_HANDLED;
>  }
>  
>  static int lpc32xx_adc_probe(struct platform_device *pdev)
>  {
> -	struct lpc32xx_adc_info *info = NULL;
> +	struct lpc32xx_adc_state *st = NULL;
>  	struct resource *res;
>  	int retval = -ENODEV;
>  	struct iio_dev *iodev = NULL;
> @@ -144,23 +144,23 @@ static int lpc32xx_adc_probe(struct platform_device *pdev)
>  		return -ENXIO;
>  	}
>  
> -	iodev = devm_iio_device_alloc(&pdev->dev, sizeof(*info));
> +	iodev = devm_iio_device_alloc(&pdev->dev, sizeof(*st));
>  	if (!iodev)
>  		return -ENOMEM;
>  
> -	info = iio_priv(iodev);
> +	st = iio_priv(iodev);
>  
> -	info->adc_base = devm_ioremap(&pdev->dev, res->start,
> -						resource_size(res));
> -	if (!info->adc_base) {
> +	st->adc_base = devm_ioremap(&pdev->dev, res->start,
> +				    resource_size(res));
> +	if (!st->adc_base) {
>  		dev_err(&pdev->dev, "failed mapping memory\n");
>  		return -EBUSY;
>  	}
>  
> -	info->clk = devm_clk_get(&pdev->dev, NULL);
> -	if (IS_ERR(info->clk)) {
> +	st->clk = devm_clk_get(&pdev->dev, NULL);
> +	if (IS_ERR(st->clk)) {
>  		dev_err(&pdev->dev, "failed getting clock\n");
> -		return PTR_ERR(info->clk);
> +		return PTR_ERR(st->clk);
>  	}
>  
>  	irq = platform_get_irq(pdev, 0);
> @@ -170,7 +170,7 @@ static int lpc32xx_adc_probe(struct platform_device *pdev)
>  	}
>  
>  	retval = devm_request_irq(&pdev->dev, irq, lpc32xx_adc_isr, 0,
> -				  LPC32XXAD_NAME, info);
> +				  LPC32XXAD_NAME, st);
>  	if (retval < 0) {
>  		dev_err(&pdev->dev, "failed requesting interrupt\n");
>  		return retval;
> @@ -178,7 +178,7 @@ static int lpc32xx_adc_probe(struct platform_device *pdev)
>  
>  	platform_set_drvdata(pdev, iodev);
>  
> -	init_completion(&info->completion);
> +	init_completion(&st->completion);
>  
>  	iodev->name = LPC32XXAD_NAME;
>  	iodev->dev.parent = &pdev->dev;
> 


^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [PATCH 3/3] staging:iio:adc:lpc32xx Move out of staging.
  2017-02-05 13:07 ` [PATCH 3/3] staging:iio:adc:lpc32xx Move out of staging Jonathan Cameron
@ 2017-02-11 11:22   ` Jonathan Cameron
  0 siblings, 0 replies; 7+ messages in thread
From: Jonathan Cameron @ 2017-02-11 11:22 UTC (permalink / raw)
  To: linux-iio; +Cc: Roland Stigge

On 05/02/17 13:07, Jonathan Cameron wrote:
> There are a few more little cleanups that could be done on this driver, but
> I don't think any are sufficient to justify not moving it out of staging.
> 
> It's a very simple driver (presumably for a simple part) so not much that can
> go wrong.  I think it was only ever in staging because that's where IIO was
> as a whole at the time and then we forgot about it!
> 
> Signed-off-by: Jonathan Cameron <jic23@kernel.org>
> Cc: Roland Stigge <stigge@antcom.de>
Applied to the togreg branch of iio.git and pushed out as testing for the
autobuilders to play with it.

Reviews still welcome.  We can fix stuff just as easily with it out of
staging as we could when it was still in staging so I see now reason to delay
moving it.

Thanks,

Jonathan
> ---
>  drivers/iio/adc/Kconfig               |  12 ++
>  drivers/iio/adc/Makefile              |   1 +
>  drivers/iio/adc/lpc32xx_adc.c         | 219 ++++++++++++++++++++++++++++++++++
>  drivers/staging/iio/adc/Kconfig       |  12 --
>  drivers/staging/iio/adc/Makefile      |   1 -
>  drivers/staging/iio/adc/lpc32xx_adc.c | 219 ----------------------------------
>  6 files changed, 232 insertions(+), 232 deletions(-)
> 
> diff --git a/drivers/iio/adc/Kconfig b/drivers/iio/adc/Kconfig
> index 789a5fb7c0be..d777a972586d 100644
> --- a/drivers/iio/adc/Kconfig
> +++ b/drivers/iio/adc/Kconfig
> @@ -305,6 +305,18 @@ config LPC18XX_ADC
>  	  To compile this driver as a module, choose M here: the module will be
>  	  called lpc18xx_adc.
>  
> +config LPC32XX_ADC
> +	tristate "NXP LPC32XX ADC"
> +	depends on ARCH_LPC32XX || COMPILE_TEST
> +	depends on HAS_IOMEM
> +	help
> +	  Say yes here to build support for the integrated ADC inside the
> +	  LPC32XX SoC. Note that this feature uses the same hardware as the
> +	  touchscreen driver, so you should either select only one of the two
> +	  drivers (lpc32xx_adc or lpc32xx_ts) or, in the OpenFirmware case,
> +	  activate only one via device tree selection.  Provides direct access
> +	  via sysfs.
> +
>  config LTC2485
>  	tristate "Linear Technology LTC2485 ADC driver"
>  	depends on I2C
> diff --git a/drivers/iio/adc/Makefile b/drivers/iio/adc/Makefile
> index 19e48af43b97..b11bb5767543 100644
> --- a/drivers/iio/adc/Makefile
> +++ b/drivers/iio/adc/Makefile
> @@ -30,6 +30,7 @@ obj-$(CONFIG_IMX7D_ADC) += imx7d_adc.o
>  obj-$(CONFIG_INA2XX_ADC) += ina2xx-adc.o
>  obj-$(CONFIG_LP8788_ADC) += lp8788_adc.o
>  obj-$(CONFIG_LPC18XX_ADC) += lpc18xx_adc.o
> +obj-$(CONFIG_LPC32XX_ADC) += lpc32xx_adc.o
>  obj-$(CONFIG_LTC2485) += ltc2485.o
>  obj-$(CONFIG_MAX1027) += max1027.o
>  obj-$(CONFIG_MAX11100) += max11100.o
> diff --git a/drivers/iio/adc/lpc32xx_adc.c b/drivers/iio/adc/lpc32xx_adc.c
> new file mode 100644
> index 000000000000..0de709b4288b
> --- /dev/null
> +++ b/drivers/iio/adc/lpc32xx_adc.c
> @@ -0,0 +1,219 @@
> +/*
> + *  lpc32xx_adc.c - Support for ADC in LPC32XX
> + *
> + *  3-channel, 10-bit ADC
> + *
> + *  Copyright (C) 2011, 2012 Roland Stigge <stigge@antcom.de>
> + *
> + *  This program is free software; you can redistribute it and/or modify
> + *  it under the terms of the GNU General Public License as published by
> + *  the Free Software Foundation; either version 2 of the License, or
> + *  (at your option) any later version.
> + *
> + *  This program is distributed in the hope that it will be useful,
> + *  but WITHOUT ANY WARRANTY; without even the implied warranty of
> + *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
> + *  GNU General Public License for more details.
> + *
> + *  You should have received a copy of the GNU General Public License
> + *  along with this program; if not, write to the Free Software
> + *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
> + */
> +
> +#include <linux/module.h>
> +#include <linux/platform_device.h>
> +#include <linux/interrupt.h>
> +#include <linux/device.h>
> +#include <linux/kernel.h>
> +#include <linux/slab.h>
> +#include <linux/io.h>
> +#include <linux/clk.h>
> +#include <linux/err.h>
> +#include <linux/completion.h>
> +#include <linux/of.h>
> +
> +#include <linux/iio/iio.h>
> +#include <linux/iio/sysfs.h>
> +
> +/*
> + * LPC32XX registers definitions
> + */
> +#define LPC32XXAD_SELECT(x)	((x) + 0x04)
> +#define LPC32XXAD_CTRL(x)	((x) + 0x08)
> +#define LPC32XXAD_VALUE(x)	((x) + 0x48)
> +
> +/* Bit definitions for LPC32XXAD_SELECT: */
> +/* constant, always write this value! */
> +#define LPC32XXAD_REFm         0x00000200
> +/* constant, always write this value! */
> +#define LPC32XXAD_REFp		0x00000080
> + /* multiple of this is the channel number: 0, 1, 2 */
> +#define LPC32XXAD_IN		0x00000010
> +/* constant, always write this value! */
> +#define LPC32XXAD_INTERNAL	0x00000004
> +
> +/* Bit definitions for LPC32XXAD_CTRL: */
> +#define LPC32XXAD_STROBE	0x00000002
> +#define LPC32XXAD_PDN_CTRL	0x00000004
> +
> +/* Bit definitions for LPC32XXAD_VALUE: */
> +#define LPC32XXAD_VALUE_MASK	0x000003FF
> +
> +#define LPC32XXAD_NAME "lpc32xx-adc"
> +
> +struct lpc32xx_adc_state {
> +	void __iomem *adc_base;
> +	struct clk *clk;
> +	struct completion completion;
> +
> +	u32 value;
> +};
> +
> +static int lpc32xx_read_raw(struct iio_dev *indio_dev,
> +			    struct iio_chan_spec const *chan,
> +			    int *val,
> +			    int *val2,
> +			    long mask)
> +{
> +	struct lpc32xx_adc_state *st = iio_priv(indio_dev);
> +
> +	if (mask == IIO_CHAN_INFO_RAW) {
> +		mutex_lock(&indio_dev->mlock);
> +		clk_prepare_enable(st->clk);
> +		/* Measurement setup */
> +		__raw_writel(LPC32XXAD_INTERNAL | (chan->address) |
> +			     LPC32XXAD_REFp | LPC32XXAD_REFm,
> +			     LPC32XXAD_SELECT(st->adc_base));
> +		/* Trigger conversion */
> +		__raw_writel(LPC32XXAD_PDN_CTRL | LPC32XXAD_STROBE,
> +			     LPC32XXAD_CTRL(st->adc_base));
> +		wait_for_completion(&st->completion); /* set by ISR */
> +		clk_disable_unprepare(st->clk);
> +		*val = st->value;
> +		mutex_unlock(&indio_dev->mlock);
> +
> +		return IIO_VAL_INT;
> +	}
> +
> +	return -EINVAL;
> +}
> +
> +static const struct iio_info lpc32xx_adc_iio_info = {
> +	.read_raw = &lpc32xx_read_raw,
> +	.driver_module = THIS_MODULE,
> +};
> +
> +#define LPC32XX_ADC_CHANNEL(_index) {			\
> +	.type = IIO_VOLTAGE,				\
> +	.indexed = 1,					\
> +	.channel = _index,				\
> +	.info_mask_separate = BIT(IIO_CHAN_INFO_RAW),	\
> +	.address = LPC32XXAD_IN * _index,		\
> +	.scan_index = _index,				\
> +}
> +
> +static const struct iio_chan_spec lpc32xx_adc_iio_channels[] = {
> +	LPC32XX_ADC_CHANNEL(0),
> +	LPC32XX_ADC_CHANNEL(1),
> +	LPC32XX_ADC_CHANNEL(2),
> +};
> +
> +static irqreturn_t lpc32xx_adc_isr(int irq, void *dev_id)
> +{
> +	struct lpc32xx_adc_state *st = dev_id;
> +
> +	/* Read value and clear irq */
> +	st->value = __raw_readl(LPC32XXAD_VALUE(st->adc_base)) &
> +		LPC32XXAD_VALUE_MASK;
> +	complete(&st->completion);
> +
> +	return IRQ_HANDLED;
> +}
> +
> +static int lpc32xx_adc_probe(struct platform_device *pdev)
> +{
> +	struct lpc32xx_adc_state *st = NULL;
> +	struct resource *res;
> +	int retval = -ENODEV;
> +	struct iio_dev *iodev = NULL;
> +	int irq;
> +
> +	res = platform_get_resource(pdev, IORESOURCE_MEM, 0);
> +	if (!res) {
> +		dev_err(&pdev->dev, "failed to get platform I/O memory\n");
> +		return -ENXIO;
> +	}
> +
> +	iodev = devm_iio_device_alloc(&pdev->dev, sizeof(*st));
> +	if (!iodev)
> +		return -ENOMEM;
> +
> +	st = iio_priv(iodev);
> +
> +	st->adc_base = devm_ioremap(&pdev->dev, res->start,
> +				    resource_size(res));
> +	if (!st->adc_base) {
> +		dev_err(&pdev->dev, "failed mapping memory\n");
> +		return -EBUSY;
> +	}
> +
> +	st->clk = devm_clk_get(&pdev->dev, NULL);
> +	if (IS_ERR(st->clk)) {
> +		dev_err(&pdev->dev, "failed getting clock\n");
> +		return PTR_ERR(st->clk);
> +	}
> +
> +	irq = platform_get_irq(pdev, 0);
> +	if (irq <= 0) {
> +		dev_err(&pdev->dev, "failed getting interrupt resource\n");
> +		return -ENXIO;
> +	}
> +
> +	retval = devm_request_irq(&pdev->dev, irq, lpc32xx_adc_isr, 0,
> +				  LPC32XXAD_NAME, st);
> +	if (retval < 0) {
> +		dev_err(&pdev->dev, "failed requesting interrupt\n");
> +		return retval;
> +	}
> +
> +	platform_set_drvdata(pdev, iodev);
> +
> +	init_completion(&st->completion);
> +
> +	iodev->name = LPC32XXAD_NAME;
> +	iodev->dev.parent = &pdev->dev;
> +	iodev->info = &lpc32xx_adc_iio_info;
> +	iodev->modes = INDIO_DIRECT_MODE;
> +	iodev->channels = lpc32xx_adc_iio_channels;
> +	iodev->num_channels = ARRAY_SIZE(lpc32xx_adc_iio_channels);
> +
> +	retval = devm_iio_device_register(&pdev->dev, iodev);
> +	if (retval)
> +		return retval;
> +
> +	dev_info(&pdev->dev, "LPC32XX ADC driver loaded, IRQ %d\n", irq);
> +
> +	return 0;
> +}
> +
> +#ifdef CONFIG_OF
> +static const struct of_device_id lpc32xx_adc_match[] = {
> +	{ .compatible = "nxp,lpc3220-adc" },
> +	{},
> +};
> +MODULE_DEVICE_TABLE(of, lpc32xx_adc_match);
> +#endif
> +
> +static struct platform_driver lpc32xx_adc_driver = {
> +	.probe		= lpc32xx_adc_probe,
> +	.driver		= {
> +		.name	= LPC32XXAD_NAME,
> +		.of_match_table = of_match_ptr(lpc32xx_adc_match),
> +	},
> +};
> +
> +module_platform_driver(lpc32xx_adc_driver);
> +
> +MODULE_AUTHOR("Roland Stigge <stigge@antcom.de>");
> +MODULE_DESCRIPTION("LPC32XX ADC driver");
> +MODULE_LICENSE("GPL");
> diff --git a/drivers/staging/iio/adc/Kconfig b/drivers/staging/iio/adc/Kconfig
> index 0ad5c44042b2..e17efb03bac0 100644
> --- a/drivers/staging/iio/adc/Kconfig
> +++ b/drivers/staging/iio/adc/Kconfig
> @@ -80,16 +80,4 @@ config AD7280
>  	  To compile this driver as a module, choose M here: the
>  	  module will be called ad7280a
>  
> -config LPC32XX_ADC
> -	tristate "NXP LPC32XX ADC"
> -	depends on ARCH_LPC32XX || COMPILE_TEST
> -	depends on HAS_IOMEM
> -	help
> -	  Say yes here to build support for the integrated ADC inside the
> -	  LPC32XX SoC. Note that this feature uses the same hardware as the
> -	  touchscreen driver, so you should either select only one of the two
> -	  drivers (lpc32xx_adc or lpc32xx_ts) or, in the OpenFirmware case,
> -	  activate only one via device tree selection.  Provides direct access
> -	  via sysfs.
> -
>  endmenu
> diff --git a/drivers/staging/iio/adc/Makefile b/drivers/staging/iio/adc/Makefile
> index e7098dedeb75..bf18bdd7c99d 100644
> --- a/drivers/staging/iio/adc/Makefile
> +++ b/drivers/staging/iio/adc/Makefile
> @@ -10,4 +10,3 @@ obj-$(CONFIG_AD7780) += ad7780.o
>  obj-$(CONFIG_AD7816) += ad7816.o
>  obj-$(CONFIG_AD7192) += ad7192.o
>  obj-$(CONFIG_AD7280) += ad7280a.o
> -obj-$(CONFIG_LPC32XX_ADC) += lpc32xx_adc.o
> diff --git a/drivers/staging/iio/adc/lpc32xx_adc.c b/drivers/staging/iio/adc/lpc32xx_adc.c
> deleted file mode 100644
> index 0de709b4288b..000000000000
> --- a/drivers/staging/iio/adc/lpc32xx_adc.c
> +++ /dev/null
> @@ -1,219 +0,0 @@
> -/*
> - *  lpc32xx_adc.c - Support for ADC in LPC32XX
> - *
> - *  3-channel, 10-bit ADC
> - *
> - *  Copyright (C) 2011, 2012 Roland Stigge <stigge@antcom.de>
> - *
> - *  This program is free software; you can redistribute it and/or modify
> - *  it under the terms of the GNU General Public License as published by
> - *  the Free Software Foundation; either version 2 of the License, or
> - *  (at your option) any later version.
> - *
> - *  This program is distributed in the hope that it will be useful,
> - *  but WITHOUT ANY WARRANTY; without even the implied warranty of
> - *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
> - *  GNU General Public License for more details.
> - *
> - *  You should have received a copy of the GNU General Public License
> - *  along with this program; if not, write to the Free Software
> - *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
> - */
> -
> -#include <linux/module.h>
> -#include <linux/platform_device.h>
> -#include <linux/interrupt.h>
> -#include <linux/device.h>
> -#include <linux/kernel.h>
> -#include <linux/slab.h>
> -#include <linux/io.h>
> -#include <linux/clk.h>
> -#include <linux/err.h>
> -#include <linux/completion.h>
> -#include <linux/of.h>
> -
> -#include <linux/iio/iio.h>
> -#include <linux/iio/sysfs.h>
> -
> -/*
> - * LPC32XX registers definitions
> - */
> -#define LPC32XXAD_SELECT(x)	((x) + 0x04)
> -#define LPC32XXAD_CTRL(x)	((x) + 0x08)
> -#define LPC32XXAD_VALUE(x)	((x) + 0x48)
> -
> -/* Bit definitions for LPC32XXAD_SELECT: */
> -/* constant, always write this value! */
> -#define LPC32XXAD_REFm         0x00000200
> -/* constant, always write this value! */
> -#define LPC32XXAD_REFp		0x00000080
> - /* multiple of this is the channel number: 0, 1, 2 */
> -#define LPC32XXAD_IN		0x00000010
> -/* constant, always write this value! */
> -#define LPC32XXAD_INTERNAL	0x00000004
> -
> -/* Bit definitions for LPC32XXAD_CTRL: */
> -#define LPC32XXAD_STROBE	0x00000002
> -#define LPC32XXAD_PDN_CTRL	0x00000004
> -
> -/* Bit definitions for LPC32XXAD_VALUE: */
> -#define LPC32XXAD_VALUE_MASK	0x000003FF
> -
> -#define LPC32XXAD_NAME "lpc32xx-adc"
> -
> -struct lpc32xx_adc_state {
> -	void __iomem *adc_base;
> -	struct clk *clk;
> -	struct completion completion;
> -
> -	u32 value;
> -};
> -
> -static int lpc32xx_read_raw(struct iio_dev *indio_dev,
> -			    struct iio_chan_spec const *chan,
> -			    int *val,
> -			    int *val2,
> -			    long mask)
> -{
> -	struct lpc32xx_adc_state *st = iio_priv(indio_dev);
> -
> -	if (mask == IIO_CHAN_INFO_RAW) {
> -		mutex_lock(&indio_dev->mlock);
> -		clk_prepare_enable(st->clk);
> -		/* Measurement setup */
> -		__raw_writel(LPC32XXAD_INTERNAL | (chan->address) |
> -			     LPC32XXAD_REFp | LPC32XXAD_REFm,
> -			     LPC32XXAD_SELECT(st->adc_base));
> -		/* Trigger conversion */
> -		__raw_writel(LPC32XXAD_PDN_CTRL | LPC32XXAD_STROBE,
> -			     LPC32XXAD_CTRL(st->adc_base));
> -		wait_for_completion(&st->completion); /* set by ISR */
> -		clk_disable_unprepare(st->clk);
> -		*val = st->value;
> -		mutex_unlock(&indio_dev->mlock);
> -
> -		return IIO_VAL_INT;
> -	}
> -
> -	return -EINVAL;
> -}
> -
> -static const struct iio_info lpc32xx_adc_iio_info = {
> -	.read_raw = &lpc32xx_read_raw,
> -	.driver_module = THIS_MODULE,
> -};
> -
> -#define LPC32XX_ADC_CHANNEL(_index) {			\
> -	.type = IIO_VOLTAGE,				\
> -	.indexed = 1,					\
> -	.channel = _index,				\
> -	.info_mask_separate = BIT(IIO_CHAN_INFO_RAW),	\
> -	.address = LPC32XXAD_IN * _index,		\
> -	.scan_index = _index,				\
> -}
> -
> -static const struct iio_chan_spec lpc32xx_adc_iio_channels[] = {
> -	LPC32XX_ADC_CHANNEL(0),
> -	LPC32XX_ADC_CHANNEL(1),
> -	LPC32XX_ADC_CHANNEL(2),
> -};
> -
> -static irqreturn_t lpc32xx_adc_isr(int irq, void *dev_id)
> -{
> -	struct lpc32xx_adc_state *st = dev_id;
> -
> -	/* Read value and clear irq */
> -	st->value = __raw_readl(LPC32XXAD_VALUE(st->adc_base)) &
> -		LPC32XXAD_VALUE_MASK;
> -	complete(&st->completion);
> -
> -	return IRQ_HANDLED;
> -}
> -
> -static int lpc32xx_adc_probe(struct platform_device *pdev)
> -{
> -	struct lpc32xx_adc_state *st = NULL;
> -	struct resource *res;
> -	int retval = -ENODEV;
> -	struct iio_dev *iodev = NULL;
> -	int irq;
> -
> -	res = platform_get_resource(pdev, IORESOURCE_MEM, 0);
> -	if (!res) {
> -		dev_err(&pdev->dev, "failed to get platform I/O memory\n");
> -		return -ENXIO;
> -	}
> -
> -	iodev = devm_iio_device_alloc(&pdev->dev, sizeof(*st));
> -	if (!iodev)
> -		return -ENOMEM;
> -
> -	st = iio_priv(iodev);
> -
> -	st->adc_base = devm_ioremap(&pdev->dev, res->start,
> -				    resource_size(res));
> -	if (!st->adc_base) {
> -		dev_err(&pdev->dev, "failed mapping memory\n");
> -		return -EBUSY;
> -	}
> -
> -	st->clk = devm_clk_get(&pdev->dev, NULL);
> -	if (IS_ERR(st->clk)) {
> -		dev_err(&pdev->dev, "failed getting clock\n");
> -		return PTR_ERR(st->clk);
> -	}
> -
> -	irq = platform_get_irq(pdev, 0);
> -	if (irq <= 0) {
> -		dev_err(&pdev->dev, "failed getting interrupt resource\n");
> -		return -ENXIO;
> -	}
> -
> -	retval = devm_request_irq(&pdev->dev, irq, lpc32xx_adc_isr, 0,
> -				  LPC32XXAD_NAME, st);
> -	if (retval < 0) {
> -		dev_err(&pdev->dev, "failed requesting interrupt\n");
> -		return retval;
> -	}
> -
> -	platform_set_drvdata(pdev, iodev);
> -
> -	init_completion(&st->completion);
> -
> -	iodev->name = LPC32XXAD_NAME;
> -	iodev->dev.parent = &pdev->dev;
> -	iodev->info = &lpc32xx_adc_iio_info;
> -	iodev->modes = INDIO_DIRECT_MODE;
> -	iodev->channels = lpc32xx_adc_iio_channels;
> -	iodev->num_channels = ARRAY_SIZE(lpc32xx_adc_iio_channels);
> -
> -	retval = devm_iio_device_register(&pdev->dev, iodev);
> -	if (retval)
> -		return retval;
> -
> -	dev_info(&pdev->dev, "LPC32XX ADC driver loaded, IRQ %d\n", irq);
> -
> -	return 0;
> -}
> -
> -#ifdef CONFIG_OF
> -static const struct of_device_id lpc32xx_adc_match[] = {
> -	{ .compatible = "nxp,lpc3220-adc" },
> -	{},
> -};
> -MODULE_DEVICE_TABLE(of, lpc32xx_adc_match);
> -#endif
> -
> -static struct platform_driver lpc32xx_adc_driver = {
> -	.probe		= lpc32xx_adc_probe,
> -	.driver		= {
> -		.name	= LPC32XXAD_NAME,
> -		.of_match_table = of_match_ptr(lpc32xx_adc_match),
> -	},
> -};
> -
> -module_platform_driver(lpc32xx_adc_driver);
> -
> -MODULE_AUTHOR("Roland Stigge <stigge@antcom.de>");
> -MODULE_DESCRIPTION("LPC32XX ADC driver");
> -MODULE_LICENSE("GPL");
> 


^ permalink raw reply	[flat|nested] 7+ messages in thread

end of thread, other threads:[~2017-02-11 11:22 UTC | newest]

Thread overview: 7+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2017-02-05 13:06 [PATCH 0/3] staging:iio:adc:lpc32xx cleanup and staging graduation Jonathan Cameron
2017-02-05 13:06 ` [PATCH 1/3] staging:iio:adc:lpc32xx Apply consistent prefix to local defines Jonathan Cameron
2017-02-11 11:20   ` Jonathan Cameron
2017-02-05 13:06 ` [PATCH 2/3] staging:iio:adc:lpc32xx rename local state structure to _state Jonathan Cameron
2017-02-11 11:21   ` Jonathan Cameron
2017-02-05 13:07 ` [PATCH 3/3] staging:iio:adc:lpc32xx Move out of staging Jonathan Cameron
2017-02-11 11:22   ` Jonathan Cameron

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.